<?php 

class Productos {


 public function CadastrarPro(){
    global $database;

    if(isset($_POST['cadastrarPro'])){

        $this->productName = $_POST['productName'];
        $this->productBuyPrice = $_POST['productBuyPrice'];
        $this->productSalePrice = $_POST['productSalePrice'];
        $this->productQtd = $_POST['productQtd'];
        $this->productCategory = $_POST['productCategory'];

        $verifica = $database->query("SELECT * FROM productos WHERE productName = '$this->productName'");
        if($count = mysqli_num_rows($verifica) == 1){
            echo "<script>alert('$this->productName ja foi cadastrado')</script>";
            echo "<script>window.open('productos.php','_self')</script>";
        }

        if($insert = $database->query("INSERT INTO productos(productName,productBuyPrice,productSalePrice,productQtd,productCategory)
        VALUES('$this->productName','$this->productBuyPrice','$this->productSalePrice','$this->productQtd','$this->productCategory')")){
        $message = 'Cadastrado com sucesso';
	    $url = 'productos.php';	    	
        echo "<script>window.open('alertas/alertas_good.php?message=$message&&url=$url','_self')</script>";
	 
        }else{
              echo "<script>alert('Ocorreu um erro no cadastro')</script>";
            echo "<script>window.open('productos.php','_self')</script>";
        }

    }
 }

public function EditarPro(){
    global $database;

    if(isset($_POST['editarPro'])){
        $this->id = $_POST['id'];
        $this->productName = $_POST['productName'];
        $this->productBuyPrice = $_POST['productBuyPrice'];
        $this->productSalePrice = $_POST['productSalePrice'];
        $this->productQtd = $_POST['productQtd'];
         $this->productCategory = $_POST['productCategory'];

        if($actualiza = $database->query("UPDATE productos SET productName='$this->productName',productBuyPrice='$this->productBuyPrice',productSalePrice='$this->productSalePrice',productQtd='$this->productQtd',productCategory='$this->productCategory' WHERE id='$this->id'")){
        
        $message = 'Actualizado com sucesso';
	    $url = 'productos.php';	    	
        echo "<script>window.open('alertas/alertas_good.php?message=$message&&url=$url','_self')</script>";
	 
        }else{
             echo "<script>alert('Ocorreu um erro ao editar')</script>";
            echo "<script>window.open('productos.php','_self')</script>";
        }

    }
}

public function DeletePro(){
    global $database;

    if(isset($_GET['id']) && !empty($_GET['id'])){
        $this->id = $_GET['id'];

        if($delete = $database->query("DELETE FROM productos WHERE id='$this->id'")){
            echo "<script>window.open('productos.php','_self')</script>";
        }else{
            echo "ERORORORRR DELETING PRODUCT";
        }
        
    }
}

public function ListarPro(){
    global $database;
   $listar = $database->query("SELECT * FROM productos ORDER BY productName ASC");
   return $listar;
}

public function StockProduct(){
    global $database;
    
    if(isset($_POST['stockPro'])){
       
        $id = $_POST['productName'];
        $qtd = $_POST['productQtd'];

        $buscaPro = $database->query("SELECT * FROM productos WHERE id='$id'");
        $dadosPro = $database->fetch_assoc($buscaPro);

        $quantidadeAnterior = $dadosPro['productQtd'];

        $quantidadeNova = $qtd + $quantidadeAnterior;

        if($qtd < 0){
            $message = 'O numero e negativo , operacao recusada';
            $url = 'productos.php';
            echo "<script>window.open('alertas/alertas_bad.php?message=$message&&url=$url','_self')</script>";
        }else{
            $updateQtd = $database->query("UPDATE productos SET productQtd='$quantidadeNova' WHERE id='$id'");
            echo "<script>alert('Quantidade estoque actualizada com sucesso')</script>";
            echo "<script>window.open('productos.php','_self')</script>";
        }
    }
}

public function ListarSelect(){
    global $database;
$listar = $database->query("SELECT * FROM productos ORDER BY productName ASC");
while($row = $database->fetch_assoc($listar)){
    $id = $row['id'];
    $producto = ucfirst($row['productName']);
    echo "<option value='$id'>$producto</option>";
}

}

public function ListarCategoriaGrosso(){
    global $database;
$listar = $database->query("SELECT * FROM productos WHERE productCategory='A Grosso'");
while($row = $database->fetch_assoc($listar)){
    $id = $row['id'];
    $producto = $row['productName'];
    echo "<option value='$id'>$producto</option>";
    }
}

public function ListarCategoriaRetalho(){
    global $database;
$listarRetalho = $database->query("SELECT * FROM productos WHERE productCategory='A Retalho'");
while($row = $database->fetch_assoc($listarRetalho)){
    $id = $row['id'];
    $producto = $row['productName'];
    echo "<option value='$id'>$producto</option>";
    }
}


public function Transferencia(){
    global $database;

    if(isset($_POST['transfer'])){
        $idAgrosso = $_POST['Agrosso'];
        $idAretalho = $_POST['Aretalho'];
        $productQtdGrosso = $_POST['productQtdGrosso'];
        $productQtdRetalho = $_POST['productQtdRetalho'];

        $buscaGrosso = $database->query("SELECT * FROM productos WHERE id='$idAgrosso'");
        $dadosPro = $database->fetch_assoc($buscaGrosso);
        $quantidadeGrosso = $dadosPro['productQtd'];

        $buscaRetalho = $database->query("SELECT * FROM productos WHERE id='$idAretalho'");
        $dadosPro = $database->fetch_assoc($buscaRetalho);
        $quantidadeAretalho = $dadosPro['productQtd'];

        if($productQtdGrosso > $quantidadeGrosso){
            echo "<script>alert('Quantidade superir ao estoque so temos $quantidadeGrosso disponivel')</script>";
        echo "<script>window.open('productos.php','_self')</script>";
        }else{
        $quantidadeNovaGrosso = $quantidadeGrosso - $productQtdGrosso;
        $quantidadeNovaRetalho = $quantidadeAretalho + $productQtdRetalho;

        $update1 = $database->query("UPDATE productos SET productQtd = '$quantidadeNovaGrosso' WHERE id='$idAgrosso'");
        $update2 = $database->query("UPDATE productos SET productQtd = '$quantidadeNovaRetalho' WHERE id='$idAretalho'");

        echo "<script>alert('Quantidade transferida com sucesso')</script>";
        echo "<script>window.open('productos.php','_self')</script>";
        }
    }
}


}
$producto = new Productos();
?>