<?php include "includes/header.php";?>

<?php include "includes/navbar.php";?>

  <div id="wrapper">

    <!-- Sidebar -->
   <?php include "includes/sidebar.php";?>

    <div id="content-wrapper">

      <div class="container-fluid">

        <!-- Breadcrumbs-->
        <ol class="breadcrumb">
          <li class="breadcrumb-item">
            <a href="#">Ola</a>
          </li>
          <li class="breadcrumb-item active"><?php echo $_SESSION['nome'];?></li>
        </ol>

        <!-- Icon Cards-->
        <div class="row">
		
         <div class="container">
             
             <!-- Button trigger modal -->
<button type="button" class="btn btn-success btn-sm" data-toggle="modal" data-target="#exampleModal">
  <i class="fas fa-fw fa-plus"></i> Cadastrar producto
</button>

<!-- Modal -->
<div class="modal fade" id="exampleModal" tabindex="-1" role="dialog" aria-labelledby="exampleModalLabel" aria-hidden="true">
  <div class="modal-dialog" role="document">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title" id="exampleModalLabel">Productos</h5>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
      <div class="modal-body">
          <div class="container">
              <div class="col-sm-10">
                  
             
          <form action="" method="post" enctype="multipart/form-data">
		    <?php $producto->CadastrarPro();?>
			<div class="form-group">
			  <label for="productName">Nome do producto</label>
			  <input type="text" name="productName" class="form-control" autocomplete="off" required/>
			 </div>
			 
			 <div class="form-group">
			  <label for="prouctBuyPrice">Preco de compra</label>
			  <input type="number" name="productBuyPrice" class="form-control" autocomplete="off" required/>
			 </div>
	
			 <div class="form-group">
			  <label for="productSalePrice">Preco de venda</label>
			  <input type="number" name="productSalePrice" class="form-control" autocomplete="off" required/>
			 </div>
			 
			 <div class="form-group">
			  <label for="productQtd">Quantidade</label>
			  <input type="number" name="productQtd" class="form-control" autocomplete="off" required/>
			 </div>

        <div class="form-group">
			  <label for="productCategory">Categoria</label>
			  <select required name="productCategory" class="form-control">
          <option></option>
          <option>A Grosso</option>
          <option>A Retalho</option>
        </select>
			 </div>
			
			 <div class="form-group">
			  <input type="submit" name="cadastrarPro" class="btn btn-primary btn-block" value="Enviar"/>
			 </div>
	
		   </form>
         </div>
          </div>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-secondary" data-dismiss="modal">Fechar</button>
      </div>
    </div>
  </div>
</div>



             <!-- Button trigger modal -->
<button type="button" class="btn btn-primary btn-sm" data-toggle="modal" data-target="#exampleModalStock">
  <i class="fas fa-fw fa-plus"></i> Stock
</button>

<!-- Modal -->
<div class="modal fade" id="exampleModalStock" tabindex="-1" role="dialog" aria-labelledby="exampleModalLabel" aria-hidden="true">
  <div class="modal-dialog" role="document">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title" id="exampleModalLabel">Stock de Productos</h5>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
      <div class="modal-body">
          <div class="container">
              <div class="col-sm-10">                 
             
          <form action="" method="post" enctype="multipart/form-data">
		    <?php $producto->StockProduct();?>
			<div class="form-group">
			  <label for="productName">Nome do producto</label>
			  <select required name="productName" class="form-control">
          <option></option>
          <?php $producto->ListarSelect();?>
        </select>
			 </div>
			 			 
			 <div class="form-group">
			  <label for="productQtd">Quantidade</label>
			  <input type="number" name="productQtd" class="form-control" autocomplete="off" required/>
			 </div>
			
			 <div class="form-group">
			  <input type="submit" name="stockPro" class="btn btn-primary btn-block" value="Enviar"/>
			 </div>
	
		   </form>
         </div>
          </div>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-secondary" data-dismiss="modal">Fechar</button>
      </div>
    </div>
  </div>
</div>


             <!-- Button trigger modal -->
<button type="button" class="btn btn-info btn-sm" data-toggle="modal" data-target="#exampleModalStockChange">
  <i class="fas fa-fw fa-minus"></i> Transferir Stock
</button>

<!-- Modal -->
<div class="modal fade" id="exampleModalStockChange" tabindex="-1" role="dialog" aria-labelledby="exampleModalLabel" aria-hidden="true">
  <div class="modal-dialog" role="document">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title" id="exampleModalLabel">Transferir stock de grosso a retalho</h5>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
      <div class="modal-body">
          <div class="container">
              <div class="col-sm-10">                 
             
          <form action="" method="post" enctype="multipart/form-data">
		    <?php $producto->Transferencia();?>
			<div class="form-group">
			  <label for="productName">Producto a Grosso</label>
			  <select required name="Agrosso" class="form-control">
          <option></option>
          <?php $producto->ListarCategoriaGrosso();?>
        </select>
			 </div>

       	<div class="form-group">
			  <label for="productName">Producto a Retalho</label>
			  <select required name="Aretalho" class="form-control">
          <option></option>
          <?php $producto->ListarCategoriaRetalho();?>
        </select>
			 </div>
			 			 
			 <div class="form-group">
			  <label for="productQtd">Quantidade a Grosso</label>
			  <input type="number" name="productQtdGrosso" class="form-control" autocomplete="off" required/>
			 </div>

       <div class="form-group">
			  <label for="productQtd">Quantidade equivalente a Retalho</label>
			  <input type="number" name="productQtdRetalho" class="form-control" autocomplete="off" required/>
			 </div>
			
			 <div class="form-group">
			  <input type="submit" name="transfer" class="btn btn-primary btn-block" value="Enviar"/>
			 </div>
	
		   </form>
         </div>
          </div>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-secondary" data-dismiss="modal">Fechar</button>
      </div>
    </div>
  </div>
</div>
 <br> <br>
 <div class="container-fluid">

<!-- Breadcrumbs-->

<!-- DataTables Example -->
<div class="card mb-3">
  <div class="card-header">
    <i class="fas fa-table"></i>
    <b>Lista de productos</b></div>
  <div class="card-body">
    <div class="table-responsive">
      <table class="table table-bordered" id="dataTable" width="100%" cellspacing="0">
        <thead>
          <tr>
            <th>Item</th>
            <th>Nome do producto</th>
            <th>Preco de compra</th>
            <th>Preco de venda</th>
            <th>Stock</th>
            <th>Categoria</th>
             <th>Editar</th>
            <th>Apagar</th>
          </tr>
        </thead>
       
        <tbody>
            
          <?php 
          $item =1;
          $lista = $producto->ListarPro();
          while($row = $database->fetch_assoc($lista)){
          $idPro = $row['id'];
            ?>
           <tr>   
            <td><?php echo $item++;?></td>
            <td><?php echo ucfirst($row['productName']);?></td>
            <td><?php echo number_format($row['productBuyPrice'],2,",",".");?> Mzn</td>
            <td><?php echo number_format($row['productSalePrice'],2,",",".");?> Mzn</td>
            <td><?php echo $row['productQtd'];?></td>
            <td><?php echo $row['productCategory'];?></td>
                   <td>
                <!-- Button trigger modal -->
<button type="button" class="btn btn-primary btn-sm" data-toggle="modal" data-target="#exampleModalLong<?php echo $idPro;?>">
  <span><i class="fa fa-paint-brush" aria-hidden="true"></i></span>
</button></td>

<!-- Modal -->
<div class="modal fade" id="exampleModalLong<?php echo $idPro;?>" tabindex="-1" role="dialog" aria-labelledby="exampleModalLongTitle" aria-hidden="true">
  <div class="modal-dialog" role="document">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title" id="exampleModalLongTitle"><font color='red'><?php echo $row['productName'];?></font></h5>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
      <div class="modal-body">
                  <div class="container">
              <div class="col-sm-10">
                  
             
            <form action="" method="post" enctype="multipart/form-data">
		    <?php $producto->EditarPro()?>
			<div class="form-group">
			  <label for="productName">Nome do producto</label>
			  <input type="text" name="productName" class="form-control" value="<?php echo $row['productName'];?>" autocomplete="off" required/>
			 </div>
			 
			 <div class="form-group">
			  <label for="prouctBuyPrice">Preco de compra</label>
			  <input type="number" name="productBuyPrice" class="form-control" value="<?php echo $row['productBuyPrice'];?>" autocomplete="off" required/>
			 </div>
	
			 <div class="form-group">
			  <label for="productSalePrice">Preco de venda</label>
			  <input type="number" name="productSalePrice" class="form-control" value="<?php echo $row['productSalePrice'];?>" autocomplete="off" required/>
			 </div>
			 
			 <div class="form-group">
			  <label for="productQtd">Quantidade</label>
			  <input type="number" name="productQtd" class="form-control" value="<?php echo $row['productQtd'];?>" autocomplete="off" required/>
			 </div>

             <input type="hidden" name="id" value="<?php echo $idPro;?>"/>
			<div class="form-group">
			  <label for="productCategory">Categoria</label>
			  <select required name="productCategory" class="form-control">
          <option><?php echo $row['productCategory'];?></option>
          <option>A Grosso</option>
          <option>A Retalho</option>
        </select>
			 </div>
			 <div class="form-group">
			  <input type="submit" name="editarPro" class="btn btn-primary btn-block" value="Enviar"/>
			 </div>
	
		   </form>
         </div>
          </div>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
      </div>
    </div>
  </div>
</div>
        
        <?php 
if($_SESSION['nivel']==1){
    ?>      
                        <!-- Button trigger modal -->
<td><button type="button" class="btn btn-danger btn-sm" data-toggle="modal" data-target="#exampleModalLong1<?php echo $idPro;?>">
  <span><i class="fa fa-trash" aria-hidden="true"></i></span>
</button></td>

<!-- Modal -->
<div class="modal fade" id="exampleModalLong1<?php echo $idPro;?>" tabindex="-1" role="dialog" aria-labelledby="exampleModalLongTitle1" aria-hidden="true">
  <div class="modal-dialog" role="document">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title" id="exampleModalLongTitle1"></h5>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
      <div class="modal-body">
          <?php $producto->deletePro();?>
        <p><h3>Deseja eliminar <font color="red"><?php echo $row['productName'];?>?</font></h3></p>
        <button type="button" class="btn btn-danger btn-sm"><a href="productos.php?id=<?php echo $idPro;?>" style="text-decoration:none; color:white"><span>Confirmar</span></a></button>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-secondary btn-sm" data-dismiss="modal">Cancelar</button>
      </div>
    </div>
  </div>
</div>

 <?php }else{
     echo "<td>N/A</td>";
 }
          
          ?>  
          
          </tr>
        
        <?php }
          
          ?>  

         
      
   
               </tbody>
      </table>
    </div>
  </div>
  <div class="card-footer small text-muted">Jonas Dinis Chambela</div>
</div>



</div>

        </div>
      </div>
      <!-- /.container-fluid -->
		  </div>

		 </div>
        
        
        </div>

     
        

      <!-- /.container-fluid -->

      <!-- Sticky Footer -->
      <?php include "includes/footer.php";?>

    </div>
    <!-- /.content-wrapper -->

  </div>
  <!-- /#wrapper -->

  <!-- Scroll to Top Button-->
  <a class="scroll-to-top rounded" href="#page-top">
    <i class="fas fa-angle-up"></i>
  </a>

  <!-- Logout Modal-->
 <?php include "includes/logout_modal.php";?>
  <?php include "includes/sweatscripFooter.php";?>


  <!-- Bootstrap core JavaScript-->
  <script src="vendor/jquery/jquery.min.js"></script>
  <script src="vendor/bootstrap/js/bootstrap.bundle.min.js"></script>

  <!-- Core plugin JavaScript-->
  <script src="vendor/jquery-easing/jquery.easing.min.js"></script>

  <!-- Page level plugin JavaScript-->
  <script src="vendor/chart.js/Chart.min.js"></script>
  <script src="vendor/datatables/jquery.dataTables.js"></script>
  <script src="vendor/datatables/dataTables.bootstrap4.js"></script>

  <!-- Custom scripts for all pages-->
  <script src="js/sb-admin.min.js"></script>

  <!-- Demo scripts for this page-->
  <script src="js/demo/datatables-demo.js"></script>
  <script src="js/demo/chart-area-demo.js"></script>

</body>

</html>
